#!/usr/bin/python
import sys
from src.tspf.main import main

if __name__ == '__main__':
    main(sys.argv)